@@ -22,11 +22,11 @@ VSGDR::StaticData - Static data script support package for SSDT post-deployment
 
 =head1 VERSION
 
-Version 0.25
+Version 0.26
 
 =cut
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 
 sub databaseName {
@@ -209,7 +209,7 @@ sub generateScript {
     
 
     my $variabledeclaration     = "declare\t" ;
-    my $tabledeclaration        = "(\t\tStaticDataPopulationId\t\tint\tnot null\n\t,\t\t" ;
+    my $tabledeclaration        = "(\t\tStaticDataPopulationId\t\tint\tnot null identity(1,1)\n\t,\t\t" ;
     my $selectstatement         = "select\t" ;
     my $insertclause            = "insert into ${combinedName}\n\t\t\t\t\t\t(";
     my $valuesclause            = "values(";
@@ -321,7 +321,7 @@ sub generateScript {
         }
         #my @outVals = map { $ColumnNumericity{$_} == 1 ? $_ : $dbh->quote($_)  } @{$ra_row};
         my $line = do{ local $" = ", "; "@outVals" } ;
-        $valuesClause    .= "(\t" . "$lno, " . $line . ")" . "\n\t\t,\t" ;
+        $valuesClause    .= "(\t" . $line . ")" . "\n\t\t,\t" ;
         $lno++;
     }
     $valuesClause        =~ s{ \n\t\t,\t \z }{}msx;
@@ -449,13 +449,13 @@ begin try
     select * 
     from(  ${valuesClause}
         ) AS vtable 
-    ( StaticDataPopulationId, $flatcolumnlist)
+    ( $flatcolumnlist)
     )
     insert  into
             \@${tableVarName} 
-    (       StaticDataPopulationId, ${flatcolumnlist}
+    (       ${flatcolumnlist}
     )
-    select  StaticDataPopulationId, ${flatcolumnlist}
+    select  ${flatcolumnlist}
     from    src
 
     ${variabledeclaration}        
